@@ -208,6 +208,12 @@ class ZMApi (Base):
         except requests.exceptions.HTTPError as err:
             self.logger.Error ('Timezone API not found, relative timezones will be local time')
 
+    def get_apibase(self):
+        return self.api_url
+
+    def get_portalbase(self):
+        return self.portal_url
+
     def get_auth(self):
         if not self.auth_enabled:
             return ''
@@ -296,6 +302,7 @@ class ZMApi (Base):
             options (dict, optional): Various filters that will be applied to events. Defaults to {}. Available fields::
         
                 {
+                    'event_id': string # specific event ID to fetch
                     'tz': string # long form timezone (example America/New_York),
                     'from': string # string # minimum start time (including human readable
                                    # strings like '1 hour ago' or '10 minutes ago to 5 minutes ago' to create a range)
