@@ -6,6 +6,10 @@ import time
 import datetime
 import re
 from pyzm.helpers.Base import Base
+from pyzm.helpers.Media import MediaStream
+
+import time
+import requests
 
 # Class to handle Yolo based detection
 
@@ -14,7 +18,6 @@ from pyzm.helpers.Base import Base
 
 class Object(Base):
 
-    
     def __init__(self, options={}, logger=None):
 
         Base.__init__(self,logger)
@@ -39,6 +42,13 @@ class Object(Base):
     def get_classes(self):
             return self.model.get_classes()
 
+    def acquire_lock(self):
+        self.model.acquire_lock()
+
+    def release_lock(self):
+        self.model.release_lock()
+
+        
     def detect(self,image=None):
         h,w = image.shape[:2]
         b,l,c = self.model.detect(image)
